OC.L10N.register(
    "notes",
    {
    "Notes" : "Piezīmes",
    "Error" : "Kļūda",
    "New note" : "Jauna piezīme",
    "Action" : "Darbība",
    "All notes" : "Visas piezīmes",
    "Categories" : "Kategorijas",
    "No notes yet" : "Nav nevienas piezīmes",
    "Share" : "Koplietot",
    "Delete note" : "Dzēst piezīmi",
    "Remove from favorites" : "Noņemt no izlases",
    "Add to favorites" : "Pievienot izlasei",
    "Edit" : "Rediģēt",
    "Preview" : "Priekšskatīt",
    "Today" : "Šodien",
    "Yesterday" : "Vakar",
    "This week" : "Šonedēļ",
    "This month" : "Šis mēnesis",
    "Updating settings has failed." : "Iestatījumu atjaunināšana neizdevās.",
    "Uncategorized" : "Bez kategorijas",
    "Tasks" : "Uzdevumi"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
